<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Http\Request;
use Validator;
use Auth;


class UserController extends Controller
{
    public function register(Request $request)
    {
        if($request->language == 'en'){
            $rules = [
                'fname'=>'required|string',
                'lname'=>'required|string',
                'phone'=>'required|unique:users|numeric|min:10',
                'email'=> 'required|email|unique:users',
                'password'=>'required|min:6|string'
            ];
            $validator = Validator::make($request->all(),$rules);
        }else{
            $rules = [
                'fname'=>'required|string',
                'lname'=>'required|string',
                'phone'=>'required|unique:users|numeric|min:10',
                'email'=> 'required|email|unique:users',
                'password'=>'required|min:6|string'
            ];
            $messages = [
                'fname.required' => ' يجب تعبئة الاسم الأول',
                'lname.required' => 'يجب تعبئة الاسم الأخير',
                'phone.required' => 'يجب تعبئة رقم الهاتف',
                'phone.unique' => 'رقم الهاتف مستخدم',
                'phone.numeric' => 'يجب أن يتكون رقم الهاتف من أرقام',
                'phone.min' => 'يجب أن يتكون رقم الهاتف من 10 خانات',
                'email.required' => 'يجب تعبئة البريد الالكتروني',
                'email.email' => 'الرجاء ادخال البريد الالكتروني بشكل صحيح',
                'email.unique' => 'البريد الالكتروني مستخدم',
                'password.min' => 'يجب ان تتكون كلمة المرور من 6 خانات أو أكثر',
            ];
            $validator = Validator::make($request->all(),$rules,$messages);
        }



        if($validator->fails()){
            $inputs = array_keys($validator->errors()->toArray());
            return response()->json([
                'status'=>false,
                'Validations'=>$validator->errors()
            ]);
        }
        $user = new User();
        $user->CreateUser($request->fname,$request->lname,$request->phone,$request->email,$request->password);
        if($request->language == 'en'){
            return response()->json([
                'status'=>true,
                'Msg'=>'successfully registered'
            ]);
        }else{
            return response()->json([
                'status'=>true,
                'Msg'=>'تم انشاء الحساب'
            ]);
        }

    }

    public function login(Request $request){
        try{
            $token = null;
            if($request->language == 'en'){

                if(is_numeric($request->login)){
                    $rules = [
                        "login"=>"required|exists:users,phone",
                        "password"=>"required"
                    ];
                    $messages = [
                        'login.exists'=>'The Selected Phone or email is invalid',
                        'login.require'=>'The email or phone field is required'
                    ];
                    $validator = Validator::make($request->all(),$rules,$messages);
                    if($validator->fails()){
                        $inputs = array_keys($validator->errors()->toArray());
                        return response()->json([
                            'status'=>false,
                            'Msg'=>$validator->errors()->first()
                        ]);
                    }

                    if($user = User::where('phone', $request->login)->first()){
                        $user_email = $user->email;
                        $cred = ['email'=>$user_email,'password'=>$request->password];
                        $token = Auth::guard('api')->attempt($cred);
                    }
                }else{
                    $rules = [
                        "login"=>"required|exists:users,email",
                        "password"=>"required"
                    ];
                    $messages = [
                        'login.exists'=>'The Selected Phone or email is invalid',
                        'login.required'=>'The email or phone field is required'
                    ];
                    $validator = Validator::make($request->all(),$rules,$messages);
                    if($validator->fails()){
                        $inputs = array_keys($validator->errors()->toArray());
                        return response()->json([
                            'status'=>false,
                            'Msg'=>$validator->errors()->first()
                        ]);
                    }
                        $cred = ['email'=>$request->login,'password'=>$request->password];
                        $token = Auth::guard('api')->attempt($cred);
                }
            }else{

                if(is_numeric($request->login)){
                    $rules = [
                        "login"=>"required|exists:users,phone",
                        "password"=>"required"
                    ];
                    $messages = [
                        'login.required' => 'يجب تعبئة البريد الالكتروني أو رقم الهاتف',
                        'login.exists' => 'البريد الالكتروني او رقم الهاتف خاطئ',
                    ];
                    $validator = Validator::make($request->all(),$rules,$messages);
                    if($validator->fails()){
                        $inputs = array_keys($validator->errors()->toArray());
                        return response()->json([
                            'status'=>false,
                            'Msg'=>$validator->errors()->first()
                        ]);
                    }

                    if($user = User::where('phone', $request->login)->first()){
                        $user_email = $user->email;
                        $cred = $cred = ['email'=>$user_email,'password'=>$request->password];
                        $token = Auth::guard('api')->attempt($cred);
                    }
                }else{
                    $rules = [
                        "login"=>"required|exists:users,email",
                        "password"=>"required"
                    ];
                    $messages = [
                        'login.required' => 'يجب تعبئة البريد الالكتروني',
                        'login.email' => 'الرجاء ادخال البريد الالكتروني بشكل صحيح',
                        'login.exists' => 'البريد الالكتروني او رقم الهاتف خاطئ',
                    ];
                    $validator = Validator::make($request->all(),$rules,$messages);
                    if($validator->fails()){
                        $inputs = array_keys($validator->errors()->toArray());
                        return response()->json([
                            'status'=>false,
                            'Msg'=>$validator->errors()->first()
                        ]);
                    }
                        $cred = ['email'=>$request->login,'password'=>$request->password];
                        $token = Auth::guard('api')->attempt($cred);
                }

            }


            if(!$token){
                if($request->language == 'en'){
                    return response()->json([
                        'status'=> false,
                        'Msg'=> 'Password Not correct'
                    ]);
                }else{
                    return response()->json([
                        'status'=> false,
                        'Msg'=> 'كلمة السر غير صحيحة'
                    ]);
                }
            }
            $user = Auth::guard('api')->user();
            return response()->json([
                'status'=>true,
                'token'=>$token,
                'user'=>$user
            ]);
        }catch(\Exception $ex){
            return response()->json(['Something is wrong']);
        }
    }


}
